@@ -105,4 +105,15 @@ plotScatter <- function(x, y, lty = 1, lwd = 2, colLine = "red", ...) {
     m <- na.omit(cbind(x, y))
     plot(m, ...)
     lines(lowess(m), col = colLine, lwd = lwd, lty = lty)
-}
\ No newline at end of file
+}
+
+qqplot2 <- function(y, fQuant = function(q, x) qnorm(q,
+                                                     mean(x, na.rm = TRUE),
+                                                     sd(x, na.rm = TRUE)), 
+                    line = TRUE, xlab = "Theoretical Quantiles", ...) {
+    qy <- ppoints(length(y))
+    qqplot(fQuant(qy, y), y,
+           xlab = xlab, ...)
+    if (line)
+        abline(a = 0, b = 1, lty = 2)
+}
